#
# spec file for package python-jaraco.collections
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-jaraco.collections
Version:        5.1.0
Release:        2.1
Summary:        Tools to work with collections
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jaraco/jaraco.collections
Source0:        https://files.pythonhosted.org/packages/source/j/jaraco.collections/jaraco_collections-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module jaraco.classes}
BuildRequires:  %{python_module jaraco.text}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 56}
BuildRequires:  %{python_module setuptools_scm >= 3.4.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jaraco.classes
Requires:       python-jaraco.text
BuildArch:      noarch
%python_subpackages

%description
jaraco.collections Tools for working with collections.
Models and classes to supplement the stdlib ‘collections’ module.

%prep
%setup -q -n jaraco_collections-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest --doctest-modules -k "not (dummyprefix or read_newlines or report_newlines)"

%files %{python_files}
%license LICENSE
%doc docs/*.rst README.rst NEWS.rst
%{python_sitelib}/jaraco/collections
%{python_sitelib}/jaraco[_.]collections-%{version}.dist-info

%changelog
* Tue Apr  1 2025 Markéta Machová <mmachova@suse.com>
- Make it compatible with older setuptools
* Wed Mar 26 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 5.1.0:
  * Fully typed RangeMap and avoid complete iterations to find
    matches
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Delinting and package refresh.
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.0:
  * Moved collections into a package and declared as typed.
  * Deprecations and Removals
  * Removed DictFilter.
* Mon Oct  9 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 4.3.0
  * Added Mask, the inverse of a Projection.
  * Require Python 3.8 or later.
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.0:
  * ``Projection`` now accepts an iterable or callable or pattern
    for matching keys.  ``Projection`` now retains order of keys
    from the underlying mapping.
  * ``DictFilter`` is now deprecated in favor of ``Projection``.
  * ``DictFilter`` no longer accepts ``include_keys`` and
    requires ``include_pattern`` as a keyword argument.
  * In ``DictFilter``, deprecated ``include_keys`` parameter and
    usage without ``include_pattern``. Future versions will honor
    ``include_pattern`` as a required keyword argument. All other
    uses are deprecated. For uses that currently rely on
    ``include_keys``, use ``Projection`` instead/in addition.
  * ``DictFilter.__len__`` no longer relies on the iterable.
    Improves efficiency and fixes ``RecursionError`` on PyPy (#12).
* Sun Mar  5 2023 Hans-Peter Jansen <hpj@urpla.net>
- prepare test environment: correctly provide jaraco modules locally
  %%{python3_sitelib} might not be available
* Fri Dec  2 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.8.0
  * Made DictStack mutable.
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 3.7.0:
  * Added RangeMap.left.
* Tue Oct 25 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 3.6.0:
  - Revised DictFilter:
  - Fixed issue where DictFilter.__contains__ would raise a
    KeyError.
  - Relies heavily now on collections.abc.Mapping base class.
* Tue Oct 25 2022 Matej Cepl <mcepl@suse.com>
- Remove conditional definition of python_module.
* Mon Aug 29 2022 Ben Greiner <code@bnavigator.de>
- Update to v3.5.2
  * Packaging refresh.
  * Enrolled with Tidelift.
- v3.5.1
  * Fixed DictStack.__len__ and addressed recursion error on PyPy
    in __getitem__.
- v3.5.0
  * DictStack now supports the following Mapping behaviors:
  - .items()
  - casting to a dict
  - __contains__ (i.e. "x in stack")
  * Require Python 3.7 or later.
- v3.4.0: Add WeightedLookup.
- v3.3.0: Add FreezableDefaultDict.
- v3.2.0: Rely on PEP 420 for namespace package.
* Sat Dec  5 2020 Benjamin Greiner <code@bnavigator.de>
- compile cache for all python3 flavors, remove unused python2
  compile statements -- gh#openSUSE/python-rpm-macros#66
* Mon Mar  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.0
  * Require Python 3.6 or later.
* Thu Jan 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1:
  * Added pop_all function.
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add LICENSE
- Compile manually due to switch to pkgutil namespace technique
- Use fdupes
- Re-instate use of --doctest-modules to increase coverage
- Add explicit build dependency on python-six
- Update to v2.0
  * Switch to pkgutil namespace technique for the ``jaraco`` namespace.
- from 1.6.0
  * Fix DeprecationWarnings when referencing abstract base
    classes from collections module.
* Tue Aug 28 2018 dmueller@suse.com
- enable tests
* Tue Aug 28 2018 dmueller@suse.com
- filelist cleanup
* Thu Aug 23 2018 dheidler@suse.de
- Initial Package for v1.5.3
